#########
PyHelpers
#########

|Python| |Documentation| |License| |Codacy grade| |DOI|

.. |Python| image:: https://img.shields.io/pypi/pyversions/pyhelpers
    :alt: Python version
    :target: https://docs.python.org/3/
.. |Documentation| image:: https://img.shields.io/readthedocs/pyhelpers
    :alt: PyHelpers Documentation
    :target: https://pyhelpers.readthedocs.io/en/latest/
.. |License| image:: https://img.shields.io/pypi/l/pyhelpers
    :alt: License for PyHelpers
    :target: https://github.com/mikeqfu/pyhelpers/blob/master/LICENSE
.. |Codacy grade| image:: https://app.codacy.com/project/badge/Grade/c3ed8571c494450da12cb0c4d3c8c7e9
    :alt: Codacy grade for PyHelpers
    :target: https://www.codacy.com/gh/mikeqfu/pyhelpers/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=mikeqfu/pyhelpers&amp;utm_campaign=Badge_Grade
.. |DOI| image:: https://zenodo.org/badge/173177909.svg
    :alt: Zenodo - DOI
    :target: https://zenodo.org/badge/latestdoi/173177909

PyHelpers is an open-source Python package designed as a lite toolkit for facilitating data (pre)processing. It offers a miscellaneous collection of handy utilities, which could assist us in performing many common data manipulation tasks, such as reading/writing of file-like objects, handling of various types of data (e.g. geographical data and textual data) and communication with relational databases (e.g. PostgreSQL).

Resources
#########

- `Documentation <https://pyhelpers.readthedocs.io/en/latest/>`_ [`PDF <https://pyhelpers.readthedocs.io/_/downloads/en/latest/pdf/>`_]
- `Bug Tracker <https://github.com/mikeqfu/pyhelpers/issues>`_

License
#######

PyHelpers is licensed under `GNU General Public License v3 <https://github.com/mikeqfu/pyhelpers/blob/master/LICENSE>`_ or later (GPLv3+).

Cite as
#######

Qian Fu, 2020. PyHelpers: an open-source toolkit for facilitating Python users' data manipulation tasks. `doi:10.5281/zenodo.4017438 <https://doi.org/10.5281/zenodo.4017438>`_
